@@ -12,7 +12,7 @@ import re
 import random
 import datetime
 
-from .helfer import lese, chance, str_add
+from .helfer import lese, chance, str_add, aufzaehlung
 
 # Regex Pattern für Doctests
 from pyzufall.helfer import re_wort, re_worte, re_liste, re_datum
@@ -321,19 +321,20 @@ def interesse():
 	return r.choice(interessen)
 
 
-def interessen_liste(anzahl=1):
+def interessen_liste(anzahl=2):
 	"""
 	Gibt eine Liste von Interessen als String zurück.
 
-	Ohne Angabe der Anzahl wird 1 Interesse zurückgegeben.
+	Ohne Angabe der Anzahl werden 2 Interessen zurückgegeben.
 
 	.. versionadded:: 0.11
+	.. deprecated:: 0.12
 
 	.. only:: doctest
 
-		>>> s = interessen_liste()
+		>>> s = interessen_liste(1)
 
-		testst ob ergebnis in liste ist
+		testst ob ergebnis aus liste ist
 		>>> assert s in interessen
 		
 		testet ob ergebnis aus buchstaben besteht
@@ -344,7 +345,7 @@ def interessen_liste(anzahl=1):
 		>>> assert re.match(re_liste, s)
 	"""
 	_liste = r.sample(interessen, anzahl)
-	return ', '.join(_liste)
+	return aufzaehlung(_liste)
 
 
 def tier():
@@ -595,7 +596,7 @@ def geburtsdatum():
 			datetime.datetime.strptime(_s, "%d.%m.%Y").date() # kann der String in ein gültiges Datum umgewandelt werden?
 			return _s
 		except:
-			print(_s + " ist kein gültiges Datum!")
+			continue
 
 
 def datum():
@@ -616,7 +617,7 @@ def datum():
 			datetime.datetime.strptime(_s, "%d.%m.%Y").date() # kann der String in ein gültiges Datum umgewandelt werden?
 			return _s
 		except:
-			print(_s + " ist kein gültiges Datum!")
+			continue
 
 
 def sprichwort():
